@@ -6,4 +6,8 @@ def random_one(messages):
 
 
 def first(messages):
-    return messages[0]
\ No newline at end of file
+    return messages[0]
+
+
+def nop(message):
+    return message
