@@ -3,7 +3,9 @@ from abc import ABCMeta, abstractmethod
 
 class SimilarityEvaluation(metaclass=ABCMeta):
     @abstractmethod
-    def evaluation(self, src_dict, cache_dict, **kwargs): pass
+    def evaluation(self, src_dict, cache_dict, **kwargs):
+        pass
 
     @abstractmethod
-    def range(self): pass
+    def range(self):
+        pass
